@@ -22,11 +22,14 @@ from typing import Tuple, Union
 import deal
 import toolz.curried as toolz
 
+import orchid.base
 from orchid import (
     dot_net_dom_access as dna,
+    dom_project_object as dpo,
     measurement as om,
     native_subsurface_point as nsp,
     native_treatment_curve_adapter as ntc,
+    net_date_time as ndt,
     net_quantity as onq,
     reference_origins as origins,
     unit_system as units,
@@ -92,11 +95,11 @@ def subsurface_point_in_length_unit(depth_datum: origins.DepthDatum,
     return result
 
 
-class NativeStageAdapter(dna.DotNetAdapter):
+class NativeStageAdapter(dpo.DomProjectObject):
     """Adapts a .NET IStage to be more Pythonic."""
 
     def __init__(self, adaptee, calculations_factory=None):
-        super().__init__(adaptee, dna.constantly(adaptee.Well.Project))
+        super().__init__(adaptee, orchid.base.constantly(adaptee.Well.Project))
         self.calculations_factory = Calculations.FractureDiagnosticsCalculationsFactory() \
             if not calculations_factory else calculations_factory
 
@@ -112,15 +115,17 @@ class NativeStageAdapter(dna.DotNetAdapter):
                                                    'The order in which this stage was completed on its well')
     stage_type = dna.transformed_dom_property('stage_type', 'The formation connection type of this stage',
                                               as_connection_type)
-    start_time = dna.transformed_dom_property('start_time', 'The start time of the stage treatment', onq.as_datetime)
-    stop_time = dna.transformed_dom_property('stop_time', 'The stop time of the stage treatment', onq.as_datetime)
+    start_time = dna.transformed_dom_property('start_time', 'The start time of the stage treatment',
+                                              ndt.as_date_time)
+    stop_time = dna.transformed_dom_property('stop_time', 'The stop time of the stage treatment',
+                                             ndt.as_date_time)
 
     @property
     def isip(self) -> om.Quantity:
         """
         Return the instantaneous shut in pressure of this stage in project units.
         """
-        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Isip)
+        return onq.as_measurement(self.expect_project_units.PRESSURE, self.dom_object.Isip)
 
     @property
     def pnet(self) -> om.Quantity:
@@ -130,14 +135,14 @@ class NativeStageAdapter(dna.DotNetAdapter):
         The net pressure of a stage is calculated by the formula:
             pnet = isip + fluid-density * tvd - shmin (where tvd is the true vertical depth)
         """
-        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Pnet)
+        return onq.as_measurement(self.expect_project_units.PRESSURE, self.dom_object.Pnet)
 
     @property
     def shmin(self) -> om.Quantity:
         """
         Return the minimum horizontal stress of this stage in project units.
         """
-        return onq.as_measurement(self.maybe_project_units.PRESSURE, self.dom_object.Shmin)
+        return onq.as_measurement(self.expect_project_units.PRESSURE, self.dom_object.Shmin)
 
     @staticmethod
     def _sampled_quantity_name_curve_map(sampled_quantity_name):
