@@ -18,12 +18,9 @@
 """This module contains functions for converting between instances of the (Python) `Measurement` class and
 instances of .NET classes like `UnitsNet.Quantity` and `DateTime`."""
 
-
-import datetime
 from numbers import Real
 from functools import singledispatch
 
-import dateutil.tz as duz
 import toolz.curried as toolz
 
 from orchid import (
@@ -35,71 +32,11 @@ from orchid import (
 # noinspection PyUnresolvedReferences
 from Orchid.FractureDiagnostics.RatioTypes import ProppantConcentration, SlurryRate
 # noinspection PyUnresolvedReferences
-from System import DateTime, DateTimeKind, Decimal
+from System import Decimal
 # noinspection PyUnresolvedReferences
 import UnitsNet
 
 
-class NetQuantityTimeZoneError(ValueError):
-    """
-    Raised when an error occurs accessing the `TimeZoneInfo` of a .NET `DateTime` instance.
-    """
-    pass
-
-
-class NetQuantityLocalDateTimeKindError(NetQuantityTimeZoneError):
-    """
-    Raised when the `DateTime.Kind` property of a .NET `DateTime` instance is `DateTimeKind.Local`.
-    """
-    def __init__(self, net_time_point):
-        """
-        Construct an instance from a .NET DateTime point in time.
-
-        Args:
-            net_time_point: A .NET DateTime representing a specific point in time.
-        """
-        super().__init__(self, '.NET DateTime.Kind cannot be Local.', net_time_point.ToString("O"))
-
-
-class NetQuantityUnspecifiedDateTimeKindError(NetQuantityTimeZoneError):
-    """
-    Raised when the `DateTime.Kind` property of a .NET `DateTime` instance is not recognized.
-    """
-    ERROR_PREFACE = '.NET DateTime.Kind is unexpectedly Unspecified.'
-
-    ERROR_SUFFIX = """
-    Although .NET DateTime.Kind should not be Unspecified, it may be
-    safe to ignore this error by catching the exception.
-
-    However, because it unexpected, **please** report the issue to
-    Reveal Energy Services. 
-    """
-
-    def __init__(self, net_time_point):
-        """
-        Construct an instance from a .NET DateTime point in time.
-
-        Args:
-            net_time_point: A .NET DateTime representing a specific point in time.
-        """
-        super().__init__(self, NetQuantityUnspecifiedDateTimeKindError.ERROR_PREFACE,
-                         net_time_point.ToString("O"), NetQuantityUnspecifiedDateTimeKindError.ERROR_SUFFIX)
-
-
-class NetQuantityNoTzInfoError(NetQuantityTimeZoneError):
-    """
-    Raised when the `DateTime.Kind` property of a .NET `DateTime` instance is `DateTimeKind.Unspecified`.
-    """
-    def __init__(self, time_point):
-        """
-        Construct an instance from a Python point in time.
-
-        Args:
-            time_point: A Python `datetime.datetime` representing a specific point in time.
-        """
-        super().__init__(self, f'The Python time point must specify the time zone.', time_point.isoformat())
-
-
 class EqualsComparisonDetails:
     def __init__(self, tolerance: Real = 1e-4,
                  net_comparison_type: UnitsNet.ComparisonType = UnitsNet.ComparisonType.Relative):
@@ -138,30 +75,6 @@ class EqualsComparisonDetails:
         return self._comparison_type
 
 
-def as_datetime(net_time_point: DateTime) -> datetime.datetime:
-    """
-    Convert a .NET `DateTime` instance to a `datetime.datetime` instance.
-
-    Args:
-        net_time_point: A point in time of type .NET `DateTime`.
-
-    Returns:
-        The `datetime.datetime` equivalent to the `net_time_point`.
-    """
-    if net_time_point.Kind == DateTimeKind.Utc:
-        return datetime.datetime(net_time_point.Year, net_time_point.Month, net_time_point.Day,
-                                 net_time_point.Hour, net_time_point.Minute, net_time_point.Second,
-                                 net_time_point.Millisecond * 1000, duz.UTC)
-
-    if net_time_point.Kind == DateTimeKind.Unspecified:
-        raise NetQuantityUnspecifiedDateTimeKindError(net_time_point)
-
-    if net_time_point.Kind == DateTimeKind.Local:
-        raise NetQuantityLocalDateTimeKindError(net_time_point)
-
-    raise ValueError(f'Unknown .NET DateTime.Kind, {net_time_point.Kind}.')
-
-
 #
 # Although Pint supports the unit `cu_ft`, we have chosen to use the synonym, `ft ** 3` (which is
 # printed as 'ft\u00b3` (that is, 'ft' followed by a Unicode superscript 3)). According to a
@@ -300,24 +213,6 @@ def as_measurement_in_specified_unit(specified_unit, net_quantity: UnitsNet.IQua
     return result
 
 
-def as_net_date_time(time_point: datetime.datetime) -> DateTime:
-    """
-    Convert a `datetime.datetime` instance to a .NET `DateTime` instance.
-
-    Args:
-        time_point: The `datetime.datetime` instance to covert.
-
-    Returns:
-        The equivalent .NET `DateTime` instance.
-    """
-    if time_point.tzinfo != duz.UTC:
-        raise NetQuantityNoTzInfoError(time_point)
-
-    return DateTime(time_point.year, time_point.month, time_point.day, time_point.hour, time_point.minute,
-                    time_point.second, microseconds_to_integral_milliseconds(time_point.microsecond),
-                    DateTimeKind.Utc)
-
-
 #
 # Although Pint supports the unit `cu_ft`, we have chosen to use the synonym, `ft ** 3` (which is
 # printed as 'ft\u00b3` (that is, 'ft' followed by a Unicode superscript 3)). According to a
@@ -483,20 +378,6 @@ def equal_net_quantities(left_quantity: UnitsNet.IQuantity, right_quantity: Unit
     return left_quantity.Equals(right_quantity, comparison_details.tolerance, comparison_details.comparison_type)
 
 
-def microseconds_to_integral_milliseconds(to_convert: int) -> int:
-    """
-    Convert microseconds to an integral number of milliseconds.
-
-    Args:
-        to_convert: The milliseconds to convert.
-
-    Returns:
-        An integral number of milliseconds equivalent to `to_convert` microseconds.
-
-    """
-    return int(round(to_convert / 1000))
-
-
 def net_decimal_to_float(net_decimal: Decimal) -> float:
     """
     Convert a .NET Decimal value to a Python float.
